@@ -122,7 +122,6 @@ impl Context {
         self.0.generate_report()
     }
 
-    /*TODO: raw surface
     #[cfg(any(target_os = "ios", target_os = "macos"))]
     pub unsafe fn create_surface_from_core_animation_layer(
         self: &Arc<Self>,
@@ -131,9 +130,12 @@ impl Context {
         let id = self.0.instance_create_surface_metal(layer, PhantomData);
         crate::Surface {
             context: Arc::clone(self),
-            id,
+            id: Surface {
+                id,
+                configured_device: Mutex::default(),
+            },
         }
-    }*/
+    }
 
     fn handle_error(
         &self,
@@ -2154,9 +2156,8 @@ impl fmt::Debug for ErrorSinkRaw {
 }
 
 fn default_error_handler(err: crate::Error) {
-    log::error!("wgpu error: {}\n", err);
-
-    panic!("Handling wgpu errors as fatal by default");
+    log::error!("Handling wgpu errors as fatal by default");
+    panic!("wgpu error: {}\n", err);
 }
 
 #[derive(Debug)]
